# Introdution of PySmart365 module
# How to install
With win key + R type `cmd` and hit enter, paste this following command:
``` Python
pip install pysmart365

```
If you have already installed it then:
``` Python
pip install --upgrade pysmart365

```
Remember that to install the `pysmart365` module you need to install the latest python version or python versions starting from python3.
# Requirements
Please install the following python modules:
``` Python
pip install --upgrade customtkinter

```


© Copyright 2023 Informatic365 - SmartSoft - MicroSoftware